PALM-meteo: palmmeteo_stdplugins.camx.CAMxPlugin Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo_stdplugins.camx.CAMxPlugin Class Reference
Inheritance diagram for palmmeteo_stdplugins.camx.CAMxPlugin:
[legend]
Collaboration diagram for palmmeteo_stdplugins.camx.CAMxPlugin:
[legend]

## Public Member Functions
def | import_data (self, fout, *args, **kwargs)
def | interpolate_horiz (self, fout, *args, **kwargs)
def | interpolate_vert (self, fout, *args, **kwargs)
def | import_data (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
def | __init__ (self, *args, **kwargs)
def | check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
def | __new__ (cls, name, bases, dct)
def | interpolate_horiz (self, *args, **kwargs)
def | interpolate_vert (self, *args, **kwargs)

## Additional Inherited Members
Public Attributes inherited from palmmeteo.plugins.Plugin
| cfg
| rt

## Member Function Documentation

## ◆ import_data()

def palmmeteo_stdplugins.camx.CAMxPlugin.import_data | ( |  | self,
|  |  | fout,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented from palmmeteo.plugins.ImportPluginMixin.

## ◆ interpolate_horiz()

def palmmeteo_stdplugins.camx.CAMxPlugin.interpolate_horiz | ( |  | self,
|  |  | fout,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented from palmmeteo.plugins.HInterpPluginMixin.

## ◆ interpolate_vert()

def palmmeteo_stdplugins.camx.CAMxPlugin.interpolate_vert | ( |  | self,
|  |  | fout,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented from palmmeteo.plugins.VInterpPluginMixin.

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/camx.py